@@ -5,10 +5,19 @@ test_that("rl_version works", {
 
   vcr::use_cassette("rl_version", {
     aa <- rl_version()
-
-    expect_is(aa, "character")
-    expect_match(aa, "[0-9]{4}-[0-9]")
   })
+  expect_is(aa, "character")
+  expect_match(aa, "[0-9]{4}-[0-9]")
+})
+
+test_that("rl_api_version works", {
+  skip_on_cran()
+
+  vcr::use_cassette("rl_api_version", {
+    aa <- rl_api_version()
+  })
+  expect_is(aa, "character")
+  expect_match(aa, "v[0-9]")
 })
 
 test_that("rl_version curl options work", {
